@@ -5,7 +5,7 @@ def get_magcluster_parser():
     
     parser = argparse.ArgumentParser(
              prog="Magcluster", 
-             description='Magnetosome gene cluster anaylise', 
+             description='Magnetosome gene cluster anaylze', 
              usage='%(prog)s [options]', 
              formatter_class=argparse.RawTextHelpFormatter, 
              epilog=
@@ -21,12 +21,12 @@ def get_magcluster_parser():
             
             "Runjia, 2021"
             )
-    parser.add_argument('-v', '--version', action='version', version='%(prog)s 0.0.8', help='show magcluster version number and exit')
+    parser.add_argument('-v', '--version', action='version', version='%(prog)s 0.0.7', help='show magcluster version number and exit')
     # parser.add_argument('-ascm', action='store_true', help='directly analyse from genome file to genecluster mapping.')
     #构建子命令
-    subparsers = parser.add_subparsers(title='Subcommands', dest="subparser_name")
+    subparsers = parser.add_subparsers(title='Options', dest="subparser_name")
     #构建maga子命令
-    parser_maga = subparsers.add_parser('maga', help='Magnetosome gene annotation with Prokka')
+    parser_maga = subparsers.add_parser('prokka', help='Genome annotation with Prokka')
     parser_maga.add_argument('fafile', type=str, help='Genome files need to be annotated', nargs='+')
 
     General = parser_maga.add_argument_group('General')
@@ -86,11 +86,15 @@ def get_magcluster_parser():
     Computation.add_argument('--rnammer', help="Prefer RNAmmer over Barrnap for rRNA prediction (default OFF)", action="store_true")
     
     #构建magsc子命令
-    parser_magsc = subparsers.add_parser('magsc', help='Magnetosome gene screening with magscreen')
-    parser_magsc.add_argument('-faa', '--faafile', required=True, type=str, help='.faa file to analyse')
-    parser_magsc.add_argument('-gbk', '--gbkfile', required=True, type=str, help='.gbk/.gbf file to analyse')
+    parser_magsc = subparsers.add_parser('mgc_screen', help='Magnetosome gene cluster screening with magscreen')
+    parser_magsc.add_argument('gbkfile', type=str, help='.gbk/.gbf files to analyzed. Multiple files or files-containing folder is acceptable.', nargs='+')
+    parser_magsc.add_argument('-th','--threshold', type=int, default=2, help="The minimum number of magnetosome genes in one contig/scaffold to screening (default '2')")
+    parser_magsc.add_argument('-o','--outdir', type=str, default='mgc_screen_XXX', help="Output folder")
+    parser_magsc.add_argument('-l', '--length', type=int, default=2000, help="Minimum length of contigs to be considered (default '2000bp')")
+    parser_magsc.add_argument('-f', '--force', help='Force overwriting existing output files (default OFF)', action="store_true")
+    
     #构建magm子命令
-    parser_magm = subparsers.add_parser('magm', help='Magnetosome gene cluster mapping with Clinker')
+    parser_magm = subparsers.add_parser('clinker', help='Magnetosome gene cluster mapping with Clinker')
     inputs = parser_magm.add_argument_group("Input options")
     inputs.add_argument('gbkfiles', help="Gene cluster GenBank files", nargs="*")
     inputs.add_argument("-r", "--ranges", 
